from setuptools import setup

setup(name='ter_ver_bb',
      version='0.0',
      description='The Bayes Formula and the Bernoulli Formula',
      packages=['ter_ver_bb'],
      author_email='poputnikov-egor1@mail.ru',
      zip_safe=False)
